Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(275)

Unified Diff: chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc

Issue 10535088: TabContentsWrapper -> TabContents, part 30. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc
diff --git a/chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc b/chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc
index ef9f12eee24f4884277033f3236db276b1b09d68..2c72c6387e3842accec8d28e15e59b99824af314 100644
--- a/chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc
+++ b/chrome/browser/tab_contents/web_drag_bookmark_handler_aura.cc
@@ -9,7 +9,7 @@
#include "chrome/browser/ui/browser_finder.h"
#include "chrome/browser/ui/browser_window.h"
#include "chrome/browser/ui/bookmarks/bookmark_tab_helper.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
+#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "content/public/browser/web_contents.h"
#include "ui/base/dragdrop/os_exchange_data.h"
#include "ui/base/dragdrop/os_exchange_data_provider_aura.h"
@@ -25,13 +25,13 @@ WebDragBookmarkHandlerAura::~WebDragBookmarkHandlerAura() {
}
void WebDragBookmarkHandlerAura::DragInitialize(WebContents* contents) {
// Ideally we would want to initialize the the TabContentsWrapper member in
// the constructor. We cannot do that as the WebDragDest object is
// created during the construction of the WebContents object. The
// TabContentsWrapper is created much later.
DCHECK(tab_ ? (tab_->web_contents() == contents) : true);
if (!tab_)
- tab_ = TabContentsWrapper::GetCurrentWrapperForContents(contents);
+ tab_ = TabContents::FromWebContents(contents);
}
void WebDragBookmarkHandlerAura::OnDragOver() {
@@ -25,13 +25,13 @@ WebDragBookmarkHandlerAura::~WebDragBookmarkHandlerAura() {
}
void WebDragBookmarkHandlerAura::DragInitialize(WebContents* contents) {
- // Ideally we would want to initialize the the TabContentsWrapper member in
+ // Ideally we would want to initialize the the TabContents member in
// the constructor. We cannot do that as the WebDragDest object is
// created during the construction of the WebContents object. The
@@ -25,13 +25,13 @@ WebDragBookmarkHandlerAura::~WebDragBookmarkHandlerAura() {
// the constructor. We cannot do that as the WebDragDest object is
// created during the construction of the WebContents object. The
- // TabContentsWrapper is created much later.
+ // TabContents is created much later.
DCHECK(tab_ ? (tab_->web_contents() == contents) : true);
if (!tab_)

Powered by Google App Engine
This is Rietveld 408576698